/* dark colormap */

@define-color theme_base_color #333333;
@define-color theme_text_color #eeeeec;
@define-color theme_bg_color #393f3f;
@define-color theme_fg_color @theme_text_color;
@define-color theme_selected_bg_color #3465a4;
@define-color theme_selected_fg_color @theme_text_color;

@define-color placeholder_text_color shade(@theme_text_color, 0.4);

@define-color theme_unfocused_base_color @theme_base_color;
@define-color theme_unfocused_text_color mix(@theme_unfocused_base_color, @theme_text_color, 0.8);
@define-color theme_unfocused_fg_color mix(@theme_unfocused_bg_color, @theme_text_color, 0.3);
@define-color theme_unfocused_bg_color @theme_bg_color;
@define-color theme_unfocused_selected_bg_color @unfocused_borders;
@define-color theme_unfocused_selected_fg_color @theme_selected_fg_color;
@define-color unfocused_button_background @theme_unfocused_bg_color;
@define-color unfocused_borders mix(@theme_unfocused_bg_color, @theme_text_color, 0.15);
@define-color unfocused_insensitive_borders mix(@theme_unfocused_bg_color, @unfocused_borders, 0.5);
@define-color unfocused_insensitive_fg_color mix(@insensitive_fg_color, @insensitive_bg_color, 0.3);
@define-color unfocused_insensitive_bg_color @insensitive_bg_color;
@define-color unfocused_dark_bg mix(@theme_unfocused_bg_color, @borders, 0.5);

@define-color menu_bg_color #555753;
@define-color menu_fg_color @theme_text_color;

@define-color menu_controls_color #aaa8ac;

@define-color menu_combobox_border darker (@theme_selected_bg_color);
@define-color menu_separator mix (@menu_fg_color, @menu_bg_color, 0.95);

@define-color theme_tooltip_bg_color #000000;
@define-color theme_tooltip_fg_color #eeeeee;

@define-color button_gradient_color_a shade (@theme_bg_color, 1.15);
@define-color button_gradient_color_b @theme_bg_color;
@define-color button_gradient_color_c shade (@theme_bg_color, 0.8);
@define-color borders #24282a;

@define-color button_active_text @theme_selected_bg_color;
@define-color button_active_text_shadow alpha(black, 0.6);
@define-color button_text_shadow alpha(black, 0.7);
@define-color primary_toolbar_button_text_shadow alpha(black, 0.1);

@define-color button_active_gradient_color_a shade (@button_gradient_color_b, 0.7);
@define-color button_active_gradient_color_b shade (@button_gradient_color_a, 0.7);

@define-color button_hover_gradient_color_a shade (@button_gradient_color_a, 1.10);
@define-color button_hover_gradient_color_b shade (@button_gradient_color_b, 1.02);

@define-color button_raised_gradient_color_a @button_gradient_color_a;
@define-color button_raised_gradient_color_b @button_gradient_color_b;
@define-color button_raised_linked_shadow alpha(#000000, 0.14);

@define-color button_raised_active_gradient_color_a @button_raised_gradient_color_b;
@define-color button_raised_active_gradient_color_b @button_raised_gradient_color_a;

@define-color insensitive_fg_color #535555;
@define-color insensitive_bg_color mix(@theme_bg_color, @theme_base_color, 0.6);
@define-color insensitive_borders #535555;

@define-color inactive_frame_color shade (@theme_bg_color, 0.8);

@define-color notebook_active_tab_border shade (@theme_selected_bg_color, 0.5);
@define-color notebook_selected_tab_color alpha (@theme_selected_bg_color, 0.75);

@define-color notebook_tab_gradient_a shade(@theme_bg_color, 0.8);
@define-color notebook_tab_gradient_b shade(@theme_bg_color, 0.75);
@define-color notebook_tab_hilight shade(@theme_bg_color, 0.9);

@define-color switch_slider_color shade(@theme_bg_color, 0.9);
@define-color switch_slider_active_border shade(@switch_trough_active_bg_a, 0.60);
@define-color switch_slider_insensitive_bg @theme_bg_color;

@define-color switch_trough_active_color @theme_text_color;
@define-color switch_trough_active_bg_a shade(@theme_selected_bg_color, 0.6);
@define-color switch_trough_active_bg_b @theme_selected_bg_color;

@define-color highlighted_border @borders;
@define-color internal_element_color #595959;
@define-color internal_element_prelight #eeeeee;
@define-color internal_element_insensitive mix(@internal_element_color, @theme_base_color, 0.65);

@define-color progressbar_background_a shade(@theme_selected_bg_color, 1.15);
@define-color progressbar_background_b shade(@theme_selected_bg_color, 0.8);
@define-color progressbar_pattern @progressbar_background_b;
@define-color progressbar_border @switch_slider_active_border;
@define-color progressbar_unfocused_background @unfocused_borders;
@define-color progressbar_unfocused_border @theme_unfocused_fg_color;

@define-color entry_text_color #ffffff;
@define-color entry_background_a shade(@theme_base_color, 0.85);
@define-color entry_background_b @theme_base_color;

@define-color entry_inset alpha(black, 0.15);


@define-color frame_color #707070;

@define-color focused_entry_border @theme_selected_bg_color;
@define-color focused_entry_inset alpha (@theme_selected_bg_color, 0.50);

@define-color toolbar_gradient_a shade(@theme_bg_color, 0.75);
@define-color toolbar_gradient_b shade(@theme_bg_color, 0.8);
@define-color toolbar_gradient_c shade(@theme_bg_color, 0.9);

@define-color toolbar_active_button_color #222222;
@define-color toolbar_border_top shade(@borders, 0.7);
@define-color toolbar_border_bottom shade(@borders, 1.05);

@define-color toolbar_button_prelight alpha(black, 0.3);

@define-color primary_toolbar_entry_bg #ffffff;
@define-color primary_toolbar_entry_fg #2e3436;

@define-color expander_row_selected_color alpha (@theme_base_color, 0.60);

@define-color inset_light_color alpha(white, 0.05);
@define-color inset_dark_color alpha(black, 0.25);

@define-color keyboard_focus_border_a alpha (@theme_fg_color, 0.30);
@define-color keyboard_focus_border_b alpha (@theme_fg_color, 0.10);

@define-color sidebar_bg shade (@theme_bg_color, 1.02);

@define-color trough_bg_color_a #30312f;
@define-color trough_bg_color_b #41433f;

@define-color scrollbar_trough shade(@theme_bg_color, 1.2);
@define-color scrollbar_trough_insensitive shade(@theme_bg_color, 1.05); /* FIXME */
@define-color scrollbar_trough shade(@theme_unfocused_bg_color, 1.2);
@define-color scrollbar_slider mix(@scrollbar_trough, @theme_fg_color, 0.15);
@define-color scrollbar_slider_prelight mix(@scrollbar_trough, @theme_fg_color, 0.3);
@define-color scrollbar_slider_active @theme_selected_bg_color;
@define-color scrollbar_slider_insensitive alpha(black, 0); /* FIXME should be transparent */
@define-color scrollbar_slider_unfocused shade(@theme_unfocused_base_color, 0.8);

@define-color treeview_focus_border shade (@theme_selected_bg_color, 1.20);

@define-color scale_fill shade (@insensitive_borders, 0.90);
@define-color scale_border_a shade (@internal_element_color, 0.90);
@define-color scale_border_b shade (@internal_element_color, 0.65);

/* FIXME: needs dark colors from here */
@define-color link_color #4a90d9;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);

@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #ccc;
@define-color os_chrome_selected_bg_color #333;
@define-color os_chrome_selected_fg_color white;

@define-color chrome_bg_color #1e1a17;
@define-color chrome_fg_color #fff;

@define-color scale_progress_fill #2c85e2;
@define-color scale_progress_border #1864b2;
@define-color scale_progress_border_b #3e90e5;

@define-color wm_title @theme_fg_color;
@define-color wm_unfocused_title @theme_unfocused_fg_color;
@define-color wm_highlight shade(@theme_bg_color, 1.4);
@define-color wm_title_highlight_dark @button_text_shadow;
@define-color wm_title_highlight alpha(#000000, 0.0);

@define-color wm_bg_a shade (@theme_bg_color, 1.3);
@define-color wm_bg_b @theme_bg_color;

@define-color wm_button_bg_a shade (@theme_bg_color, 1.0);
@define-color wm_button_bg_b shade (@theme_bg_color, 0.85);
@define-color wm_button_bg_c shade (@theme_bg_color, 0.8);
@define-color wm_button_bg_d shade (@theme_bg_color, 0.9);

@define-color wm_button_bg_hover_a shade (@wm_button_bg_a, 1.2);
@define-color wm_button_bg_hover_b shade (@wm_button_bg_b, 1.2);
@define-color wm_button_bg_hover_c shade (@wm_button_bg_c, 1.2);
@define-color wm_button_bg_hover_d shade (@wm_button_bg_d, 1.2);

@define-color wm_button_bg_active_a shade (@theme_bg_color, 0.5);
@define-color wm_button_bg_active_b shade (@theme_bg_color, 0.7);
@define-color wm_button_bg_active_c shade (@theme_bg_color, 0.7);

@import url("gtk-widgets-backgrounds.css");
@import url("gtk-widgets-borders-dark.css");
@import url("gtk-widgets-assets-dark.css");
@import url("gtk-widgets.css");
/* @import url("gtk-scrollbar-experiments.css"); */
@import url("gtk-widgets-dark-overrides.css");
@import url("gnome-applications.css");
