GtkIconView.view.cell:selected,
GtkIconView.view.cell:selected:focus {
    background-color: alpha(@theme_base_color, 0.0);

    border-style: solid;
    border-radius: 10px;
    border-width: 3px;
    border-color: #d3d7cf;

    /* FIXME: this probably needs to be better;
     * see https://bugzilla.gnome.org/show_bug.cgi?id=644157
     */
    -adwaita-focus-border-color: alpha(@theme_text_color, 0.4);
    -adwaita-focus-border-radius: 5;
    -adwaita-focus-border-dashes: true;
}

.button,
GtkComboBox {
    text-shadow: @button_text_shadow 0 -1;
}

.button *:active,
GtkComboBox *:active {
    text-shadow: @button_active_text_shadow 0 1;
    color: @theme_selected_bg_color; /* Not sure about this one */
}

.button *:active:insensitive,
GtkComboBox *:active:insensitive {
    text-shadow: none;
    color: @insensitive_fg_color;
}

.toolbar .button.raised *,
.toolbar .raised .button *,
.inline-toolbar .button * {
    icon-shadow: @button_text_shadow 0 -1;
}

.toolbar .button.raised *:active,
.toolbar .raised .button *:active,
.inline-toolbar .button *:active {
    icon-shadow: @button_active_text_shadow 0 -1;
}

.toolbar .button.raised *:insensitive,
.toolbar .raised .button *:insensitive,
.inline-toolbar .button *:insensitive {
    icon-shadow: none;
}

.toolbar .button.raised *:backdrop,
.toolbar .raised .button *:backdrop,
.inline-toolbar .button *:backdrop {
    icon-shadow: none;
}

column-header.button,
column-header .button {
    text-shadow: none;
}


.spinbutton .button {
    icon-shadow: none;
}

.button .separator,
.button .separator:prelight {
    color: alpha (@theme_text_color, 0.1);
}

GtkScale.trough:insensitive:backdrop { /* not working */
    background-color: transparent;
}

GtkSwitch.slider {
    background-image: -gtk-gradient (linear,
                                     left top, left bottom,
                                     from (@theme_bg_color),
                                     to (@switch_slider_color));

    -adwaita-switch-grip-color: shade (@switch_slider_color, 0.9);
    border-color: mix (@borders, black, 0.4);
    box-shadow: 0 -1 inset alpha(white, 0.04), 
                0 1 inset shade(@theme_bg_color, 1.1),
                0 2 inset alpha(@borders, 0.2);
}

.scrollbar.trough.vertical {
    box-shadow: none;
}

.scrollbar.trough.horizontal {
    box-shadow: none;
}

.primary-toolbar .toolbar,
.primary-toolbar.toolbar {
    box-shadow: 0 3 inset alpha(black, 0.05),
                0 2 inset alpha(black, 0.05),
                0 1 inset alpha(black, 0.05);
}

.entry:focus {
    box-shadow: 2 2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                -2 -2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                1 1 inset alpha(lighter(@theme_selected_bg_color), 0.7),
                -1 -1 inset alpha(lighter(@theme_selected_bg_color), 0.7);
}

GtkComboBox.combobox-entry .entry:focus:first-child {
    box-shadow: 2 2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                -1 -2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                1 1 inset alpha(lighter(@theme_selected_bg_color), 0.7),
                0 -1 inset alpha(lighter(@theme_selected_bg_color), 0.7);
}

GtkComboBox.combobox-entry .entry:focus:last-child {
    box-shadow: 1 2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                -2 -2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                0 1 inset alpha(lighter(@theme_selected_bg_color), 0.7),
                -1 -1 inset alpha(lighter(@theme_selected_bg_color), 0.7);
}

.spinbutton .button:active,
.spinbutton .button:active:focus {
    box-shadow: 1 0 inset @inset_dark_color,
                0 2 inset alpha(lighter(@theme_selected_bg_color), 0.2),
                0 -2 inset alpha(lighter(@theme_selected_bg_color), 0.2), 
                0 1 inset alpha(lighter(@theme_selected_bg_color), 0.7), 
                0 -1 inset alpha(lighter(@theme_selected_bg_color), 0.7);
}

.spinbutton .button:first-child:active,
.spinbutton .button:first-child:active:focus {
    box-shadow: 2 2 inset alpha(lighter(@theme_selected_bg_color), 0.2), 
                0 -2 inset alpha(lighter(@theme_selected_bg_color), 0.2), 
                1 1 inset alpha(lighter(@theme_selected_bg_color), 0.7), 
                0 -1 inset alpha(lighter(@theme_selected_bg_color), 0.7);
}

.spinbutton .button:last-child:active,
.spinbutton .button:last-child:active:focus {
    box-shadow: 1 0 inset @inset_dark_color, 
                0 2 inset alpha(lighter(@theme_selected_bg_color), 0.2), 
                -2 -2 inset alpha(lighter(@theme_selected_bg_color), 0.2), 
                0 1 inset alpha(lighter(@theme_selected_bg_color), 0.7),
                -1 -1 inset alpha(lighter(@theme_selected_bg_color), 0.7);
}
